// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: proto/agent/v1/connection.proto
// Protobuf C++ Version: 7.35.1

#include "proto/agent/v1/connection.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::agent::v1::UpdateAgentConnection
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto, /* tracker*/ nullptr,},
        // ::agent::v1::SendNodeInstances
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto, /* tracker*/ nullptr,},
        // ::agent::v1::AgentConfig
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto, /* tracker*/ nullptr,},
        // ::agent::v1::CloudConfig
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto, /* tracker*/ nullptr,},
        // ::agent::v1::Config
        {&::_pbi::kDescriptorMethods, &::descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace agent {
namespace v1 {
class CloudConfig::_Internal {
 public:
  using HasBits = decltype(::std::declval<CloudConfig>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_._has_bits_);
};

constexpr CloudConfig::ParseTableT_ CloudConfig::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::agent::v1::CloudConfig>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string alert_notifications = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_.alert_notifications_)}},
      // string dashboards = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_.dashboards_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string dashboards = 1;
      {PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_.dashboards_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string alert_notifications = 2;
      {PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_.alert_notifications_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\24\12\23\0\0\0\0\0"
      "agent.v1.CloudConfig"
      "dashboards"
      "alert_notifications"
    }},
  };
}


inline constexpr CloudConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        dashboards_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        alert_notifications_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr CloudConfig::CloudConfig(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL CloudConfig::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) CloudConfig(arena);
}
constexpr auto CloudConfig::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(CloudConfig), alignof(CloudConfig));
}
constexpr auto CloudConfig::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &CloudConfig::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<CloudConfig>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &CloudConfig::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<CloudConfig>(), &CloudConfig::ByteSizeLong,
              &CloudConfig::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(CloudConfig, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct CloudConfigGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr CloudConfigGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 CloudConfig_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(CloudConfig::InternalGenerateClassData_(
            _default, &CloudConfig_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<CloudConfig>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~CloudConfigGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) CloudConfig _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<CloudConfig>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(CloudConfigGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST CloudConfigGlobalsTypeInternal CloudConfig_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* CloudConfig_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return CloudConfig_globals_.GetClassData();
#else
  return CloudConfig_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class AgentConfig::_Internal {
 public:
  using HasBits = decltype(::std::declval<AgentConfig>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_._has_bits_);
};

constexpr AgentConfig::ParseTableT_ AgentConfig::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_._has_bits_),
      0, // no _extensions_
      2, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967292,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::agent::v1::AgentConfig>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string alert_notifications = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_.alert_notifications_)}},
      // string dashboards = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_.dashboards_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string dashboards = 1;
      {PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_.dashboards_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // string alert_notifications = 2;
      {PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_.alert_notifications_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\24\12\23\0\0\0\0\0"
      "agent.v1.AgentConfig"
      "dashboards"
      "alert_notifications"
    }},
  };
}


inline constexpr AgentConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        dashboards_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        alert_notifications_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr AgentConfig::AgentConfig(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL AgentConfig::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) AgentConfig(arena);
}
constexpr auto AgentConfig::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(AgentConfig), alignof(AgentConfig));
}
constexpr auto AgentConfig::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &AgentConfig::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<AgentConfig>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &AgentConfig::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<AgentConfig>(), &AgentConfig::ByteSizeLong,
              &AgentConfig::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(AgentConfig, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct AgentConfigGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr AgentConfigGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 AgentConfig_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(AgentConfig::InternalGenerateClassData_(
            _default, &AgentConfig_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<AgentConfig>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~AgentConfigGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) AgentConfig _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<AgentConfig>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(AgentConfigGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST AgentConfigGlobalsTypeInternal AgentConfig_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* AgentConfig_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return AgentConfig_globals_.GetClassData();
#else
  return AgentConfig_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class UpdateAgentConnection::_Internal {
 public:
  using HasBits = decltype(::std::declval<UpdateAgentConnection>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_._has_bits_);
};

constexpr UpdateAgentConnection::ParseTableT_ UpdateAgentConnection::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_._has_bits_),
      0, // no _extensions_
      17, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294852480,  // skipmap
      offsetof(ParseTableT_, field_entries),
      10,  // num_field_entries
      4,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::agent::v1::UpdateAgentConnection>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .google.protobuf.Duration agent_uptime = 16;
      {::_pbi::TcParser::FastMtS2,
       {386, 4, 2,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.agent_uptime_)}},
      // string claim_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.claim_id_)}},
      // bool reachable = 2;
      {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(UpdateAgentConnection, _impl_.reachable_), 6>(),
       {16, 6, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.reachable_)}},
      // int64 session_id = 3;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(UpdateAgentConnection, _impl_.session_id_), 5>(),
       {24, 5, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.session_id_)}},
      // .agent.v1.ConnectionUpdateSource update_source = 4;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(UpdateAgentConnection, _impl_.update_source_), 7>(),
       {32, 7, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.update_source_)}},
      // string mqtt_broker_addr = 5;
      {::_pbi::TcParser::FastUS1,
       {42, 1, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.mqtt_broker_addr_)}},
      // .google.protobuf.Timestamp updated_at = 6;
      {::_pbi::TcParser::FastMtS1,
       {50, 2, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.updated_at_)}},
      // int32 vmq_instance_id = 7;
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(UpdateAgentConnection, _impl_.vmq_instance_id_), 8>(),
       {56, 8, 0,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.vmq_instance_id_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      // .google.protobuf.Duration system_uptime = 15;
      {::_pbi::TcParser::FastMtS1,
       {122, 3, 1,
        PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.system_uptime_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string claim_id = 1;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.claim_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // bool reachable = 2;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.reachable_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
      // int64 session_id = 3;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.session_id_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // .agent.v1.ConnectionUpdateSource update_source = 4;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.update_source_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // string mqtt_broker_addr = 5;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.mqtt_broker_addr_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .google.protobuf.Timestamp updated_at = 6;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.updated_at_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // int32 vmq_instance_id = 7;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.vmq_instance_id_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
      // .google.protobuf.Duration system_uptime = 15;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.system_uptime_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.protobuf.Duration agent_uptime = 16;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.agent_uptime_), _Internal::kHasBitsOffset + 4, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .aclk_lib.v1.Capability capabilities = 17;
      {PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.capabilities_), _Internal::kHasBitsOffset + 9, 3, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Duration>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Duration_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Duration>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Duration_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::aclk_lib::v1::Capability>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::aclk_lib::v1::Capability_globals_},
        #endif
    }},
    {{
      "\36\10\0\0\0\20\0\0\0\0\0\0\0\0\0\0"
      "agent.v1.UpdateAgentConnection"
      "claim_id"
      "mqtt_broker_addr"
    }},
  };
}


inline constexpr UpdateAgentConnection::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        mqtt_broker_addr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        updated_at_{nullptr},
        system_uptime_{nullptr},
        agent_uptime_{nullptr},
        session_id_{::int64_t{0}},
        reachable_{false},
        update_source_{static_cast< ::agent::v1::ConnectionUpdateSource >(0)},
        vmq_instance_id_{0},
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::agent::v1::UpdateAgentConnection,
            PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.capabilities_)>()
         }
     {}

template <typename>
constexpr UpdateAgentConnection::UpdateAgentConnection(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL UpdateAgentConnection::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) UpdateAgentConnection(arena);
}
constexpr auto UpdateAgentConnection::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(UpdateAgentConnection), alignof(UpdateAgentConnection));
}
constexpr auto UpdateAgentConnection::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &UpdateAgentConnection::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<UpdateAgentConnection>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &UpdateAgentConnection::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<UpdateAgentConnection>(), &UpdateAgentConnection::ByteSizeLong,
              &UpdateAgentConnection::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct UpdateAgentConnectionGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr UpdateAgentConnectionGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 UpdateAgentConnection_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(UpdateAgentConnection::InternalGenerateClassData_(
            _default, &UpdateAgentConnection_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<UpdateAgentConnection>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~UpdateAgentConnectionGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) UpdateAgentConnection _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<UpdateAgentConnection>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(UpdateAgentConnectionGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST UpdateAgentConnectionGlobalsTypeInternal UpdateAgentConnection_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* UpdateAgentConnection_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return UpdateAgentConnection_globals_.GetClassData();
#else
  return UpdateAgentConnection_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class Config::_Internal {
 public:
  using HasBits = decltype(::std::declval<Config>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(Config, _impl_._has_bits_);
};

constexpr Config::ParseTableT_ Config::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(Config, _impl_._has_bits_),
      0, // no _extensions_
      5, 8,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967271,  // skipmap
      offsetof(ParseTableT_, field_entries),
      2,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::agent::v1::Config>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .agent.v1.AgentConfig agent_config = 4;
      {::_pbi::TcParser::FastMtS1,
       {34, 0, 0,
        PROTOBUF_FIELD_OFFSET(Config, _impl_.agent_config_)}},
      // .agent.v1.CloudConfig cloud_config = 5;
      {::_pbi::TcParser::FastMtS1,
       {42, 1, 1,
        PROTOBUF_FIELD_OFFSET(Config, _impl_.cloud_config_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .agent.v1.AgentConfig agent_config = 4;
      {PROTOBUF_FIELD_OFFSET(Config, _impl_.agent_config_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .agent.v1.CloudConfig cloud_config = 5;
      {PROTOBUF_FIELD_OFFSET(Config, _impl_.cloud_config_), _Internal::kHasBitsOffset + 1, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::agent::v1::AgentConfig>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::agent::v1::AgentConfig_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::agent::v1::CloudConfig>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::agent::v1::CloudConfig_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr Config::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        agent_config_{nullptr},
        cloud_config_{nullptr} {}

template <typename>
constexpr Config::Config(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL Config::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) Config(arena);
}
constexpr auto Config::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(Config), alignof(Config));
}
constexpr auto Config::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &Config::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<Config>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &Config::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<Config>(), &Config::ByteSizeLong,
              &Config::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(Config, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ConfigGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ConfigGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 Config_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(Config::InternalGenerateClassData_(
            _default, &Config_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<Config>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ConfigGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) Config _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<Config>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ConfigGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ConfigGlobalsTypeInternal Config_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* Config_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return Config_globals_.GetClassData();
#else
  return Config_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class SendNodeInstances::_Internal {
 public:
  using HasBits = decltype(::std::declval<SendNodeInstances>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_._has_bits_);
};

constexpr SendNodeInstances::ParseTableT_ SendNodeInstances::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_._has_bits_),
      0, // no _extensions_
      3, 24,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967288,  // skipmap
      offsetof(ParseTableT_, field_entries),
      3,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::agent::v1::SendNodeInstances>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string claim_id = 1;
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.claim_id_)}},
      // .agent.v1.Config config = 2;
      {::_pbi::TcParser::FastMtS1,
       {18, 2, 0,
        PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.config_)}},
      // string space_id = 3;
      {::_pbi::TcParser::FastUS1,
       {26, 1, 0,
        PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.space_id_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string claim_id = 1;
      {PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.claim_id_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .agent.v1.Config config = 2;
      {PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.config_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // string space_id = 3;
      {PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_.space_id_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::agent::v1::Config>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::agent::v1::Config_globals_},
        #endif
    }},
    {{
      "\32\10\0\10\0\0\0\0"
      "agent.v1.SendNodeInstances"
      "claim_id"
      "space_id"
    }},
  };
}


inline constexpr SendNodeInstances::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        claim_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        space_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        config_{nullptr} {}

template <typename>
constexpr SendNodeInstances::SendNodeInstances(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL SendNodeInstances::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) SendNodeInstances(arena);
}
constexpr auto SendNodeInstances::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(SendNodeInstances), alignof(SendNodeInstances));
}
constexpr auto SendNodeInstances::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &SendNodeInstances::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<SendNodeInstances>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &SendNodeInstances::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<SendNodeInstances>(), &SendNodeInstances::ByteSizeLong,
              &SendNodeInstances::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(SendNodeInstances, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct SendNodeInstancesGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr SendNodeInstancesGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 SendNodeInstances_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(SendNodeInstances::InternalGenerateClassData_(
            _default, &SendNodeInstances_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<SendNodeInstances>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~SendNodeInstancesGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) SendNodeInstances _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<SendNodeInstances>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(SendNodeInstancesGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST SendNodeInstancesGlobalsTypeInternal SendNodeInstances_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* SendNodeInstances_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return SendNodeInstances_globals_.GetClassData();
#else
  return SendNodeInstances_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace agent
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_proto_2fagent_2fv1_2fconnection_2eproto[1];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_proto_2fagent_2fv1_2fconnection_2eproto = nullptr;
const ::uint32_t
    TableStruct_proto_2fagent_2fv1_2fconnection_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_._has_bits_),
        13, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.reachable_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.session_id_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.update_source_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.mqtt_broker_addr_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.updated_at_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.vmq_instance_id_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.system_uptime_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.agent_uptime_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.capabilities_),
        0,
        6,
        5,
        7,
        1,
        2,
        8,
        3,
        4,
        9,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::agent::v1::SendNodeInstances, _impl_._has_bits_),
        6, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::agent::v1::SendNodeInstances, _impl_.claim_id_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::SendNodeInstances, _impl_.config_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::SendNodeInstances, _impl_.space_id_),
        0,
        2,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::agent::v1::AgentConfig, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::agent::v1::AgentConfig, _impl_.dashboards_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::AgentConfig, _impl_.alert_notifications_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::agent::v1::CloudConfig, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::agent::v1::CloudConfig, _impl_.dashboards_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::CloudConfig, _impl_.alert_notifications_),
        0,
        1,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::agent::v1::Config, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::agent::v1::Config, _impl_.agent_config_),
        PROTOBUF_FIELD_OFFSET(::agent::v1::Config, _impl_.cloud_config_),
        0,
        1,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::agent::v1::UpdateAgentConnection)},
        {23, sizeof(::agent::v1::SendNodeInstances)},
        {32, sizeof(::agent::v1::AgentConfig)},
        {39, sizeof(::agent::v1::CloudConfig)},
        {46, sizeof(::agent::v1::Config)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::agent::v1::UpdateAgentConnection_globals_,
        &::agent::v1::SendNodeInstances_globals_,
        &::agent::v1::AgentConfig_globals_,
        &::agent::v1::CloudConfig_globals_,
        &::agent::v1::Config_globals_,
};
const char descriptor_table_protodef_proto_2fagent_2fv1_2fconnection_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\037proto/agent/v1/connection.proto\022\010agent"
    ".v1\032\037google/protobuf/timestamp.proto\032\036go"
    "ogle/protobuf/duration.proto\032\027proto/aclk"
    "/v1/lib.proto\"\376\002\n\025UpdateAgentConnection\022"
    "\020\n\010claim_id\030\001 \001(\t\022\021\n\treachable\030\002 \001(\010\022\022\n\n"
    "session_id\030\003 \001(\003\0227\n\rupdate_source\030\004 \001(\0162"
    " .agent.v1.ConnectionUpdateSource\022\030\n\020mqt"
    "t_broker_addr\030\005 \001(\t\022.\n\nupdated_at\030\006 \001(\0132"
    "\032.google.protobuf.Timestamp\022\027\n\017vmq_insta"
    "nce_id\030\007 \001(\005\0220\n\rsystem_uptime\030\017 \001(\0132\031.go"
    "ogle.protobuf.Duration\022/\n\014agent_uptime\030\020"
    " \001(\0132\031.google.protobuf.Duration\022-\n\014capab"
    "ilities\030\021 \003(\0132\027.aclk_lib.v1.Capability\"Y"
    "\n\021SendNodeInstances\022\020\n\010claim_id\030\001 \001(\t\022 \n"
    "\006config\030\002 \001(\0132\020.agent.v1.Config\022\020\n\010space"
    "_id\030\003 \001(\t\">\n\013AgentConfig\022\022\n\ndashboards\030\001"
    " \001(\t\022\033\n\023alert_notifications\030\002 \001(\t\">\n\013Clo"
    "udConfig\022\022\n\ndashboards\030\001 \001(\t\022\033\n\023alert_no"
    "tifications\030\002 \001(\t\"h\n\006Config\022+\n\014agent_con"
    "fig\030\004 \001(\0132\025.agent.v1.AgentConfig\022+\n\014clou"
    "d_config\030\005 \001(\0132\025.agent.v1.CloudConfigJ\004\010"
    "\001\020\004*\260\001\n\026ConnectionUpdateSource\022(\n$CONNEC"
    "TION_UPDATE_SOURCE_UNSPECIFIED\020\000\022\"\n\036CONN"
    "ECTION_UPDATE_SOURCE_AGENT\020\001\022 \n\034CONNECTI"
    "ON_UPDATE_SOURCE_LWT\020\002\022&\n\"CONNECTION_UPD"
    "ATE_SOURCE_HEURISTIC\020\003B\020Z\016agent/v1;agent"
    "b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto_deps[3] = {
        &::descriptor_table_google_2fprotobuf_2fduration_2eproto,
        &::descriptor_table_google_2fprotobuf_2ftimestamp_2eproto,
        &::descriptor_table_proto_2faclk_2fv1_2flib_2eproto,
};
static ::absl::once_flag descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto = {
    false,
    false,
    1048,
    descriptor_table_protodef_proto_2fagent_2fv1_2fconnection_2eproto,
    "proto/agent/v1/connection.proto",
    &descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto_once,
    descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto_deps,
    3,
    5,
    schemas,
    file_message_globals,
    TableStruct_proto_2fagent_2fv1_2fconnection_2eproto::offsets,
    file_level_enum_descriptors_proto_2fagent_2fv1_2fconnection_2eproto,
    file_level_service_descriptors_proto_2fagent_2fv1_2fconnection_2eproto,
};
namespace agent {
namespace v1 {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionUpdateSource_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto);
  return file_level_enum_descriptors_proto_2fagent_2fv1_2fconnection_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t ConnectionUpdateSource_internal_data_[] = {
    262144u, 0u, };
// ===================================================================

void UpdateAgentConnection::clear_updated_at() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.updated_at_ != nullptr) _impl_.updated_at_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
void UpdateAgentConnection::clear_system_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.system_uptime_ != nullptr) _impl_.system_uptime_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
void UpdateAgentConnection::clear_agent_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.agent_uptime_ != nullptr) _impl_.agent_uptime_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
void UpdateAgentConnection::clear_capabilities() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.capabilities_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000200U);
}
UpdateAgentConnection::UpdateAgentConnection(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateAgentConnection_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:agent.v1.UpdateAgentConnection)
}
PROTOBUF_NDEBUG_INLINE UpdateAgentConnection::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::agent::v1::UpdateAgentConnection& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        claim_id_(arena, from.claim_id_),
        mqtt_broker_addr_(arena, from.mqtt_broker_addr_),
        capabilities_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::agent::v1::UpdateAgentConnection,
              PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.capabilities_)>()
          , from.capabilities_
        }
     {}

UpdateAgentConnection::UpdateAgentConnection(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const UpdateAgentConnection& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, UpdateAgentConnection_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  UpdateAgentConnection* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.updated_at_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.updated_at_)
                : nullptr;
  _impl_.system_uptime_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.system_uptime_)
                : nullptr;
  _impl_.agent_uptime_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.agent_uptime_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, session_id_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, session_id_),
           offsetof(Impl_, vmq_instance_id_) -
               offsetof(Impl_, session_id_) +
               sizeof(Impl_::vmq_instance_id_));

  // @@protoc_insertion_point(copy_constructor:agent.v1.UpdateAgentConnection)
}
PROTOBUF_NDEBUG_INLINE UpdateAgentConnection::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        claim_id_(arena),
        mqtt_broker_addr_(arena),
        capabilities_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::agent::v1::UpdateAgentConnection,
            PROTOBUF_FIELD_OFFSET(::agent::v1::UpdateAgentConnection, _impl_.capabilities_)>()
         }
     {}

inline void UpdateAgentConnection::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, updated_at_),
           0,
           offsetof(Impl_, vmq_instance_id_) -
               offsetof(Impl_, updated_at_) +
               sizeof(Impl_::vmq_instance_id_));
}
UpdateAgentConnection::~UpdateAgentConnection() {
  // @@protoc_insertion_point(destructor:agent.v1.UpdateAgentConnection)
  SharedDtor(*this);
}
inline void UpdateAgentConnection::SharedDtor(MessageLite& self) {
  UpdateAgentConnection& this_ = static_cast<UpdateAgentConnection&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.claim_id_.Destroy();
  this_._impl_.mqtt_broker_addr_.Destroy();
  delete this_._impl_.updated_at_;
  delete this_._impl_.system_uptime_;
  delete this_._impl_.agent_uptime_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull UpdateAgentConnection_class_data_ =
        UpdateAgentConnection::InternalGenerateClassData_(UpdateAgentConnection_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateAgentConnection::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateAgentConnection_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(UpdateAgentConnection_class_data_.tc_table);
  return UpdateAgentConnection_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
UpdateAgentConnection::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&UpdateAgentConnection_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&UpdateAgentConnection_globals_));
  return UpdateAgentConnection_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const UpdateAgentConnection::ParseTableT_
    UpdateAgentConnection::_table_ =
        UpdateAgentConnection::InternalGenerateParseTable_(UpdateAgentConnection_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void UpdateAgentConnection::Clear() {
// @@protoc_insertion_point(message_clear_start:agent.v1.UpdateAgentConnection)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.mqtt_broker_addr_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.updated_at_ != nullptr);
      _impl_.updated_at_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.system_uptime_ != nullptr);
      _impl_.system_uptime_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.agent_uptime_ != nullptr);
      _impl_.agent_uptime_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x000000e0U)) {
    ::memset(&_impl_.session_id_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.update_source_) -
        reinterpret_cast<char*>(&_impl_.session_id_)) + sizeof(_impl_.update_source_));
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    _impl_.vmq_instance_id_ = 0;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _impl_.capabilities_.Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL UpdateAgentConnection::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const UpdateAgentConnection& this_ = static_cast<const UpdateAgentConnection&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL UpdateAgentConnection::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const UpdateAgentConnection& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:agent.v1.UpdateAgentConnection)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string claim_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.UpdateAgentConnection.claim_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // bool reachable = 2;
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_reachable() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          2, this_._internal_reachable(), target);
    }
  }

  // int64 session_id = 3;
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_session_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<3>(
              stream, this_._internal_session_id(), target);
    }
  }

  // .agent.v1.ConnectionUpdateSource update_source = 4;
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_update_source() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          4, this_._internal_update_source(), target);
    }
  }

  // string mqtt_broker_addr = 5;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_mqtt_broker_addr().empty()) {
      const ::std::string& _s = this_._internal_mqtt_broker_addr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.UpdateAgentConnection.mqtt_broker_addr");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // .google.protobuf.Timestamp updated_at = 6;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        6, *this_._impl_.updated_at_, this_._impl_.updated_at_->GetCachedSize(), target,
        stream);
  }

  // int32 vmq_instance_id = 7;
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_vmq_instance_id() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<7>(
              stream, this_._internal_vmq_instance_id(), target);
    }
  }

  // .google.protobuf.Duration system_uptime = 15;
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        15, *this_._impl_.system_uptime_, this_._impl_.system_uptime_->GetCachedSize(), target,
        stream);
  }

  // .google.protobuf.Duration agent_uptime = 16;
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        16, *this_._impl_.agent_uptime_, this_._impl_.agent_uptime_->GetCachedSize(), target,
        stream);
  }

  // repeated .aclk_lib.v1.Capability capabilities = 17;
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_capabilities_size());
         i < n; i++) {
      const auto& repfield = this_._internal_capabilities().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              17, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:agent.v1.UpdateAgentConnection)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t UpdateAgentConnection::ByteSizeLong(const MessageLite& base) {
  const UpdateAgentConnection& this_ = static_cast<const UpdateAgentConnection&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t UpdateAgentConnection::ByteSizeLong() const {
  const UpdateAgentConnection& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:agent.v1.UpdateAgentConnection)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // string claim_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string mqtt_broker_addr = 5;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_mqtt_broker_addr().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_mqtt_broker_addr());
      }
    }
    // .google.protobuf.Timestamp updated_at = 6;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.updated_at_);
    }
    // .google.protobuf.Duration system_uptime = 15;
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.system_uptime_);
    }
    // .google.protobuf.Duration agent_uptime = 16;
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 2 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.agent_uptime_);
    }
    // int64 session_id = 3;
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_session_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_session_id());
      }
    }
    // bool reachable = 2;
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_reachable() != 0) {
        total_size += 2;
      }
    }
    // .agent.v1.ConnectionUpdateSource update_source = 4;
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_update_source() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_update_source());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // int32 vmq_instance_id = 7;
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_vmq_instance_id() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_vmq_instance_id());
      }
    }
    // repeated .aclk_lib.v1.Capability capabilities = 17;
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      total_size += 2UL * this_._internal_capabilities_size();
      for (const auto& msg : this_._internal_capabilities()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void UpdateAgentConnection::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<UpdateAgentConnection*>(&to_msg);
  auto& from = static_cast<const UpdateAgentConnection&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:agent.v1.UpdateAgentConnection)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_mqtt_broker_addr().empty()) {
        _this->_internal_set_mqtt_broker_addr(from._internal_mqtt_broker_addr());
      } else {
        if (_this->_impl_.mqtt_broker_addr_.IsDefault()) {
          _this->_internal_set_mqtt_broker_addr("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.updated_at_ != nullptr);
      if (_this->_impl_.updated_at_ == nullptr) {
        _this->_impl_.updated_at_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.updated_at_);
      } else {
        _this->_impl_.updated_at_->MergeFrom(*from._impl_.updated_at_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.system_uptime_ != nullptr);
      if (_this->_impl_.system_uptime_ == nullptr) {
        _this->_impl_.system_uptime_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.system_uptime_);
      } else {
        _this->_impl_.system_uptime_->MergeFrom(*from._impl_.system_uptime_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.agent_uptime_ != nullptr);
      if (_this->_impl_.agent_uptime_ == nullptr) {
        _this->_impl_.agent_uptime_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.agent_uptime_);
      } else {
        _this->_impl_.agent_uptime_->MergeFrom(*from._impl_.agent_uptime_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_session_id() != 0) {
        _this->_impl_.session_id_ = from._impl_.session_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_reachable() != 0) {
        _this->_impl_.reachable_ = from._impl_.reachable_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_update_source() != 0) {
        _this->_impl_.update_source_ = from._impl_.update_source_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_vmq_instance_id() != 0) {
        _this->_impl_.vmq_instance_id_ = from._impl_.vmq_instance_id_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      _this->_internal_mutable_capabilities()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_capabilities());
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void UpdateAgentConnection::CopyFrom(const UpdateAgentConnection& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:agent.v1.UpdateAgentConnection)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void UpdateAgentConnection::InternalSwap(UpdateAgentConnection* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.mqtt_broker_addr_, &other->_impl_.mqtt_broker_addr_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.vmq_instance_id_)
      + sizeof(UpdateAgentConnection::_impl_.vmq_instance_id_)
      - PROTOBUF_FIELD_OFFSET(UpdateAgentConnection, _impl_.updated_at_)>(
          reinterpret_cast<char*>(&_impl_.updated_at_),
          reinterpret_cast<char*>(&other->_impl_.updated_at_));
  _impl_.capabilities_.InternalSwap(&other->_impl_.capabilities_);
}

::google::protobuf::Metadata UpdateAgentConnection::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

SendNodeInstances::SendNodeInstances(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendNodeInstances_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:agent.v1.SendNodeInstances)
}
PROTOBUF_NDEBUG_INLINE SendNodeInstances::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::agent::v1::SendNodeInstances& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        claim_id_(arena, from.claim_id_),
        space_id_(arena, from.space_id_) {}

SendNodeInstances::SendNodeInstances(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const SendNodeInstances& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, SendNodeInstances_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SendNodeInstances* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.config_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.config_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:agent.v1.SendNodeInstances)
}
PROTOBUF_NDEBUG_INLINE SendNodeInstances::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        claim_id_(arena),
        space_id_(arena) {}

inline void SendNodeInstances::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.config_ = {};
}
SendNodeInstances::~SendNodeInstances() {
  // @@protoc_insertion_point(destructor:agent.v1.SendNodeInstances)
  SharedDtor(*this);
}
inline void SendNodeInstances::SharedDtor(MessageLite& self) {
  SendNodeInstances& this_ = static_cast<SendNodeInstances&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.claim_id_.Destroy();
  this_._impl_.space_id_.Destroy();
  delete this_._impl_.config_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull SendNodeInstances_class_data_ =
        SendNodeInstances::InternalGenerateClassData_(SendNodeInstances_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendNodeInstances::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendNodeInstances_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(SendNodeInstances_class_data_.tc_table);
  return SendNodeInstances_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
SendNodeInstances::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&SendNodeInstances_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&SendNodeInstances_globals_));
  return SendNodeInstances_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const SendNodeInstances::ParseTableT_
    SendNodeInstances::_table_ =
        SendNodeInstances::InternalGenerateParseTable_(SendNodeInstances_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void SendNodeInstances::Clear() {
// @@protoc_insertion_point(message_clear_start:agent.v1.SendNodeInstances)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.claim_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.space_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.config_ != nullptr);
      _impl_.config_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL SendNodeInstances::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const SendNodeInstances& this_ = static_cast<const SendNodeInstances&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL SendNodeInstances::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const SendNodeInstances& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:agent.v1.SendNodeInstances)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string claim_id = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_claim_id().empty()) {
      const ::std::string& _s = this_._internal_claim_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.SendNodeInstances.claim_id");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .agent.v1.Config config = 2;
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.config_, this_._impl_.config_->GetCachedSize(), target,
        stream);
  }

  // string space_id = 3;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_space_id().empty()) {
      const ::std::string& _s = this_._internal_space_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.SendNodeInstances.space_id");
      target = stream->WriteStringMaybeAliased(3, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:agent.v1.SendNodeInstances)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t SendNodeInstances::ByteSizeLong(const MessageLite& base) {
  const SendNodeInstances& this_ = static_cast<const SendNodeInstances&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t SendNodeInstances::ByteSizeLong() const {
  const SendNodeInstances& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:agent.v1.SendNodeInstances)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    // string claim_id = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_claim_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_claim_id());
      }
    }
    // string space_id = 3;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_space_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_space_id());
      }
    }
    // .agent.v1.Config config = 2;
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.config_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void SendNodeInstances::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<SendNodeInstances*>(&to_msg);
  auto& from = static_cast<const SendNodeInstances&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:agent.v1.SendNodeInstances)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_claim_id().empty()) {
        _this->_internal_set_claim_id(from._internal_claim_id());
      } else {
        if (_this->_impl_.claim_id_.IsDefault()) {
          _this->_internal_set_claim_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_space_id().empty()) {
        _this->_internal_set_space_id(from._internal_space_id());
      } else {
        if (_this->_impl_.space_id_.IsDefault()) {
          _this->_internal_set_space_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.config_ != nullptr);
      if (_this->_impl_.config_ == nullptr) {
        _this->_impl_.config_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.config_);
      } else {
        _this->_impl_.config_->MergeFrom(*from._impl_.config_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void SendNodeInstances::CopyFrom(const SendNodeInstances& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:agent.v1.SendNodeInstances)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void SendNodeInstances::InternalSwap(SendNodeInstances* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.claim_id_, &other->_impl_.claim_id_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.space_id_, &other->_impl_.space_id_, arena);
  swap(_impl_.config_, other->_impl_.config_);
}

::google::protobuf::Metadata SendNodeInstances::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

AgentConfig::AgentConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AgentConfig_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:agent.v1.AgentConfig)
}
PROTOBUF_NDEBUG_INLINE AgentConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::agent::v1::AgentConfig& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        dashboards_(arena, from.dashboards_),
        alert_notifications_(arena, from.alert_notifications_) {}

AgentConfig::AgentConfig(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const AgentConfig& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, AgentConfig_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  AgentConfig* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:agent.v1.AgentConfig)
}
PROTOBUF_NDEBUG_INLINE AgentConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        dashboards_(arena),
        alert_notifications_(arena) {}

inline void AgentConfig::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
AgentConfig::~AgentConfig() {
  // @@protoc_insertion_point(destructor:agent.v1.AgentConfig)
  SharedDtor(*this);
}
inline void AgentConfig::SharedDtor(MessageLite& self) {
  AgentConfig& this_ = static_cast<AgentConfig&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.dashboards_.Destroy();
  this_._impl_.alert_notifications_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull AgentConfig_class_data_ =
        AgentConfig::InternalGenerateClassData_(AgentConfig_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AgentConfig::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AgentConfig_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(AgentConfig_class_data_.tc_table);
  return AgentConfig_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
AgentConfig::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&AgentConfig_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&AgentConfig_globals_));
  return AgentConfig_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const AgentConfig::ParseTableT_
    AgentConfig::_table_ =
        AgentConfig::InternalGenerateParseTable_(AgentConfig_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void AgentConfig::Clear() {
// @@protoc_insertion_point(message_clear_start:agent.v1.AgentConfig)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.dashboards_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.alert_notifications_.ClearNonDefaultToEmpty();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL AgentConfig::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const AgentConfig& this_ = static_cast<const AgentConfig&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL AgentConfig::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const AgentConfig& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:agent.v1.AgentConfig)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string dashboards = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_dashboards().empty()) {
      const ::std::string& _s = this_._internal_dashboards();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.AgentConfig.dashboards");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string alert_notifications = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_alert_notifications().empty()) {
      const ::std::string& _s = this_._internal_alert_notifications();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.AgentConfig.alert_notifications");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:agent.v1.AgentConfig)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t AgentConfig::ByteSizeLong(const MessageLite& base) {
  const AgentConfig& this_ = static_cast<const AgentConfig&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t AgentConfig::ByteSizeLong() const {
  const AgentConfig& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:agent.v1.AgentConfig)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string dashboards = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_dashboards().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_dashboards());
      }
    }
    // string alert_notifications = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_alert_notifications().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_alert_notifications());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void AgentConfig::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<AgentConfig*>(&to_msg);
  auto& from = static_cast<const AgentConfig&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:agent.v1.AgentConfig)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_dashboards().empty()) {
        _this->_internal_set_dashboards(from._internal_dashboards());
      } else {
        if (_this->_impl_.dashboards_.IsDefault()) {
          _this->_internal_set_dashboards("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_alert_notifications().empty()) {
        _this->_internal_set_alert_notifications(from._internal_alert_notifications());
      } else {
        if (_this->_impl_.alert_notifications_.IsDefault()) {
          _this->_internal_set_alert_notifications("");
        }
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void AgentConfig::CopyFrom(const AgentConfig& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:agent.v1.AgentConfig)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void AgentConfig::InternalSwap(AgentConfig* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.dashboards_, &other->_impl_.dashboards_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.alert_notifications_, &other->_impl_.alert_notifications_, arena);
}

::google::protobuf::Metadata AgentConfig::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

CloudConfig::CloudConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, CloudConfig_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:agent.v1.CloudConfig)
}
PROTOBUF_NDEBUG_INLINE CloudConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::agent::v1::CloudConfig& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        dashboards_(arena, from.dashboards_),
        alert_notifications_(arena, from.alert_notifications_) {}

CloudConfig::CloudConfig(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const CloudConfig& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, CloudConfig_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  CloudConfig* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:agent.v1.CloudConfig)
}
PROTOBUF_NDEBUG_INLINE CloudConfig::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        dashboards_(arena),
        alert_notifications_(arena) {}

inline void CloudConfig::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
CloudConfig::~CloudConfig() {
  // @@protoc_insertion_point(destructor:agent.v1.CloudConfig)
  SharedDtor(*this);
}
inline void CloudConfig::SharedDtor(MessageLite& self) {
  CloudConfig& this_ = static_cast<CloudConfig&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.dashboards_.Destroy();
  this_._impl_.alert_notifications_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull CloudConfig_class_data_ =
        CloudConfig::InternalGenerateClassData_(CloudConfig_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
CloudConfig::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&CloudConfig_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(CloudConfig_class_data_.tc_table);
  return CloudConfig_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
CloudConfig::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&CloudConfig_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&CloudConfig_globals_));
  return CloudConfig_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const CloudConfig::ParseTableT_
    CloudConfig::_table_ =
        CloudConfig::InternalGenerateParseTable_(CloudConfig_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void CloudConfig::Clear() {
// @@protoc_insertion_point(message_clear_start:agent.v1.CloudConfig)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.dashboards_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.alert_notifications_.ClearNonDefaultToEmpty();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL CloudConfig::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const CloudConfig& this_ = static_cast<const CloudConfig&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL CloudConfig::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const CloudConfig& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:agent.v1.CloudConfig)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string dashboards = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_dashboards().empty()) {
      const ::std::string& _s = this_._internal_dashboards();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.CloudConfig.dashboards");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string alert_notifications = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_alert_notifications().empty()) {
      const ::std::string& _s = this_._internal_alert_notifications();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "agent.v1.CloudConfig.alert_notifications");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:agent.v1.CloudConfig)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t CloudConfig::ByteSizeLong(const MessageLite& base) {
  const CloudConfig& this_ = static_cast<const CloudConfig&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t CloudConfig::ByteSizeLong() const {
  const CloudConfig& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:agent.v1.CloudConfig)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // string dashboards = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_dashboards().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_dashboards());
      }
    }
    // string alert_notifications = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_alert_notifications().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_alert_notifications());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void CloudConfig::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<CloudConfig*>(&to_msg);
  auto& from = static_cast<const CloudConfig&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:agent.v1.CloudConfig)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_dashboards().empty()) {
        _this->_internal_set_dashboards(from._internal_dashboards());
      } else {
        if (_this->_impl_.dashboards_.IsDefault()) {
          _this->_internal_set_dashboards("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_alert_notifications().empty()) {
        _this->_internal_set_alert_notifications(from._internal_alert_notifications());
      } else {
        if (_this->_impl_.alert_notifications_.IsDefault()) {
          _this->_internal_set_alert_notifications("");
        }
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void CloudConfig::CopyFrom(const CloudConfig& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:agent.v1.CloudConfig)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void CloudConfig::InternalSwap(CloudConfig* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.dashboards_, &other->_impl_.dashboards_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.alert_notifications_, &other->_impl_.alert_notifications_, arena);
}

::google::protobuf::Metadata CloudConfig::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

Config::Config(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Config_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:agent.v1.Config)
}
PROTOBUF_NDEBUG_INLINE Config::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::agent::v1::Config& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

Config::Config(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const Config& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, Config_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  Config* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.agent_config_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.agent_config_)
                : nullptr;
  _impl_.cloud_config_ = (CheckHasBit(cached_has_bits, 0x00000002U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.cloud_config_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:agent.v1.Config)
}
PROTOBUF_NDEBUG_INLINE Config::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void Config::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, agent_config_),
           0,
           offsetof(Impl_, cloud_config_) -
               offsetof(Impl_, agent_config_) +
               sizeof(Impl_::cloud_config_));
}
Config::~Config() {
  // @@protoc_insertion_point(destructor:agent.v1.Config)
  SharedDtor(*this);
}
inline void Config::SharedDtor(MessageLite& self) {
  Config& this_ = static_cast<Config&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.agent_config_;
  delete this_._impl_.cloud_config_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull Config_class_data_ =
        Config::InternalGenerateClassData_(Config_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Config::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Config_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(Config_class_data_.tc_table);
  return Config_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
Config::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&Config_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&Config_globals_));
  return Config_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const Config::ParseTableT_
    Config::_table_ =
        Config::InternalGenerateParseTable_(Config_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void Config::Clear() {
// @@protoc_insertion_point(message_clear_start:agent.v1.Config)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(_impl_.agent_config_ != nullptr);
      _impl_.agent_config_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(_impl_.cloud_config_ != nullptr);
      _impl_.cloud_config_->Clear();
    }
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL Config::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const Config& this_ = static_cast<const Config&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL Config::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const Config& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:agent.v1.Config)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .agent.v1.AgentConfig agent_config = 4;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.agent_config_, this_._impl_.agent_config_->GetCachedSize(), target,
        stream);
  }

  // .agent.v1.CloudConfig cloud_config = 5;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        5, *this_._impl_.cloud_config_, this_._impl_.cloud_config_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:agent.v1.Config)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t Config::ByteSizeLong(const MessageLite& base) {
  const Config& this_ = static_cast<const Config&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t Config::ByteSizeLong() const {
  const Config& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:agent.v1.Config)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // .agent.v1.AgentConfig agent_config = 4;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.agent_config_);
    }
    // .agent.v1.CloudConfig cloud_config = 5;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.cloud_config_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void Config::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<Config*>(&to_msg);
  auto& from = static_cast<const Config&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:agent.v1.Config)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      ABSL_DCHECK(from._impl_.agent_config_ != nullptr);
      if (_this->_impl_.agent_config_ == nullptr) {
        _this->_impl_.agent_config_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.agent_config_);
      } else {
        _this->_impl_.agent_config_->MergeFrom(*from._impl_.agent_config_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      ABSL_DCHECK(from._impl_.cloud_config_ != nullptr);
      if (_this->_impl_.cloud_config_ == nullptr) {
        _this->_impl_.cloud_config_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.cloud_config_);
      } else {
        _this->_impl_.cloud_config_->MergeFrom(*from._impl_.cloud_config_);
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void Config::CopyFrom(const Config& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:agent.v1.Config)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void Config::InternalSwap(Config* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(Config, _impl_.cloud_config_)
      + sizeof(Config::_impl_.cloud_config_)
      - PROTOBUF_FIELD_OFFSET(Config, _impl_.agent_config_)>(
          reinterpret_cast<char*>(&_impl_.agent_config_),
          reinterpret_cast<char*>(&other->_impl_.agent_config_));
}

::google::protobuf::Metadata Config::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace agent
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
